@@ -288,10 +288,26 @@ class rc():
     '''
     相关系数
     
+    参数
+    ----
+    *arg：列表类型
+    
+    属性
+    ----
+    rc_mat：相关系数矩阵
+    
     
     correlation coefficient
+    
+    Parameter
+    ---------
+    *arg: list
+    
+    Attribute
+    ---------
+    rc_mat: correlation coefficient matrix
     '''
-    def fit(self, *arg):
+    def __init__(self, *arg):
         arg = np.array(arg, dtype=float)
         if len(arg.shape) != 2:
             raise Exception("Input list should be 1-D.")
@@ -309,12 +325,16 @@ class rc():
     
     def show(self, index=None, cmap='Blues'):
         '''
+        作图并显示
+        
         参数
         ----
         index：列表形式，可选，各数组名称
         cmap：字符串形式，可选，颜色板，默认为'Blues'
         
         
+        Display the image
+        
         Parameters
         ----------
         index: list, callable, names of each array
@@ -331,6 +351,8 @@ class rc():
     
     def savefig(self, filename, index=None, cmap='Blues'):
         '''
+        作图并保存
+        
         参数
         ----
         filename：字符串形式，文件名
@@ -338,6 +360,8 @@ class rc():
         cmap：字符串形式，可选，颜色板，默认为'Blues'
         
         
+        Save the image
+        
         Parameters
         ----------
         filename: str, file name
